@@ -13,6 +13,13 @@ pub struct TableFields {
     pub rel: Vec<ForeignKeyRel>,
 }
 
+#[derive(Debug, Clone)]
+pub struct NullableForeignKeys {
+    pub column_name: String,
+    pub nullable: bool,
+    pub safe: bool,
+}
+
 #[derive(Debug, Clone)]
 pub struct Describe {
     pub field: String,
@@ -30,6 +37,7 @@ pub struct CdDt {
     pub fk: bool,
     pub non_generated: bool,
     pub dep: Option<ForeignKeyRel>,
+    pub nullable: bool,
 }
 
 #[derive(Debug, Clone)]
