@@ -1,9 +1,13 @@
 pub mod const_types {
     pub const VARCHAR: &str = "varchar";
     pub const INT: &str = "int";
+    pub const UNSIGNED_INT: &str = "int unsigned";
     pub const SMALLINT: &str = "smallint";
+    pub const UNSINGED_SMALLINT: &str = "smallint unsigned";
     pub const TINYINT: &str = "tinyint";
+    pub const UNSINGED_TINYINT: &str = "tinyint unsigned";
     pub const MEDIUMINT: &str = "mediumint";
+    pub const UNSINGED_BIGINT: &str = "bigint unsigned";
     pub const BIGINT: &str = "bigint";
     pub const DECIMAL: &str = "decimal";
     pub const FLOAT: &str = "float";
@@ -16,6 +20,11 @@ pub mod const_types {
     pub const BIT: &str = "bit";
     pub const CHAR: &str = "char";
     pub const BINARY: &str = "binary";
+    pub const VARBINARY: &str = "varbinary";
     pub const TEXT: &str = "text";
+    pub const LONG_TEXT: &str = "longtext";
+    pub const MEDIUM_TEXT: &str = "mediumtext";
     pub const BLOB: &str = "blob";
+    pub const LONG_BLOB: &str = "longblob";
+    pub const ENUM: &str = "enum";
 }
