@@ -7,7 +7,7 @@ pub struct Mysql {
 }
 
 impl Display for Mysql {
-    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+    fn fmt(&self, _f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
         for x in &self.schema {
             println!("{}", x.table_name)
         }
